
# Acknowledgements and Credits

The Lab Orchestrator project thanks


Contributors
------------

* Stefan Maak <stefan.maak@uni-greifswald.de> - Stefan made the first implementation

* Mickey Kim <mickey.kim@genomicsengland.co.uk>  ! Thanks for the phantastic cookiecutter template !


Development Lead
----------------

* mark doerr <mark.doerr@uni-greifswald.de>